@@ -5,7 +5,7 @@ use Lemonldap::NG::Common::UserAgent;
 use Lemonldap::NG::Common::Apache::Session::Generate::SHA256;
 use JSON qw(from_json to_json);
 
-our $VERSION = '2.0.0';
+our $VERSION = '2.0.5';
 
 our @ISA = qw(Lemonldap::NG::Common::Apache::Session::Generate::SHA256);
 
@@ -227,9 +227,11 @@ sub save {
           Lemonldap::NG::Handler::Main->tsv->{cipher}->encrypt(time);
     };
     print STDERR "$@\n" if ($@);
-    $req->content( to_json( $self->{data} ) );
+    my $content = to_json( $self->{data} );
+    $req->content($content);
     delete $self->{data}->{__secret};
-    $req->header( 'Content-Type' => 'application/json' );
+    $req->header( 'Content-Type'   => 'application/json' );
+    $req->header( 'Content-Length' => length($content) );
     my $resp = $self->ua->request($req);
 
     if ( $resp->is_success ) {
@@ -267,29 +269,62 @@ sub delete {
     return ( $resp->is_success ? 1 : 0 );
 }
 
+sub searchOn {
+    my ( $class, $args, $selectField, $value, @fields ) = @_;
+    return $class->_getAll( "all=1&search=$selectField,$value",
+        $args, ( @fields ? \@fields : () ) );
+}
+
 ## @method get_key_from_all_sessions()
 # Not documented.
 sub get_key_from_all_sessions() {
-    die "Not implemented";
     my ( $class, $args, $data ) = @_;
+    my $res = $class->_getAll( 'all=1', $args, $data );
+    return unless $res;
+
+    if ( ref($data) eq 'CODE' ) {
+        my $r;
+        foreach my $k ( keys %$res ) {
+            my $tmp = &$data( $res->{$k}, $k );
+            $r->{$k} = $tmp if ( defined($tmp) );
+        }
+        $res = $r;
+    }
+    return $res;
+}
+
+sub _getAll {
+    my ( $class, $query, $args, $data ) = @_;
     my $self = bless {}, $class;
-    foreach (qw(baseUrl user password realm)) {
+    foreach (qw(baseUrl user password realm lwpOpts lwpSslOpts kind)) {
         $self->{$_} = $args->{$_};
     }
+    $self->{data} = { data => ( ref($data) eq 'CODE' ? undef : $data ) };
     die('baseUrl is required') unless ( $self->{baseUrl} );
-    if ( ref($data) eq 'CODE' ) {
+    my $req = HTTP::Request->new( POST => $self->base . "?$query" );
+    eval {
+        $self->{data}->{__secret} =
+          Lemonldap::NG::Handler::Main->tsv->{cipher}->encrypt(time);
+    };
+    print STDERR "$@\n" if ($@);
+    my $content = to_json( $self->{data} );
+    $req->content($content);
+    $req->header( 'Content-Length' => length($content) );
+    delete $self->{data}->{__secret};
+    $req->header( 'Content-Type' => 'application/json' );
+    my $resp = $self->ua->request($req);
 
-        #my $r = $self->_soapCall( "get_key_from_all_sessions", $args );
-        #my $res;
-        #if ($r) {
-        #    foreach my $k ( keys %$r ) {
-        #        my $tmp = &$data( $r->{$k}, $k );
-        #        $res->{$k} = $tmp if ( defined($tmp) );
-        #    }
-        #}
+    if ( $resp->is_success ) {
+        my $res;
+        eval { $res = from_json( $resp->content, { allow_nonref => 1 } ) };
+        if ($@) {
+            die "Bad REST response: $@";
+        }
+        return $res;
     }
     else {
-        #return $self->_soapCall( "get_key_from_all_sessions", $args, $data );
+        print STDERR "REST server returns " . $resp->status_line . "\n";
+        return;
     }
 }
 
