@@ -13,7 +13,7 @@ use MIME::Base64;
 use Net::LDAP;
 use utf8;
 
-our $VERSION = '1.9.991_01';
+our $VERSION = '2.0.0';
 
 extends 'Lemonldap::NG::Common::Notifications';
 
@@ -38,6 +38,7 @@ has ldapConfBase => (
 
 has ldapBindDN => (
     is      => 'ro',
+    lazy    => 1,
     default => sub {
         $_[0]->p->logger->warn('Warning: "ldapBindDN" parameter is not set');
         return '';
@@ -226,7 +227,7 @@ sub getDone {
 sub _search {
     my ( $self, $filter ) = @_;
 
-    my $ldap = _ldap($self) or return 0;
+    my $ldap = _ldap($self);
 
     my $search = $ldap->search(
         base   => $self->{ldapConfBase},
@@ -386,8 +387,7 @@ sub _ldap {
     );
 
     unless ($ldap) {
-        $self->logger->error( 'connexion failed: ' . $@ );
-        return;
+        die 'connexion failed: ' . $@;
     }
 
     # Start TLS if needed
@@ -397,8 +397,7 @@ sub _ldap {
         $h{capath} = $self->{caPath} if ( $self->{caPath} );
         my $start_tls = $ldap->start_tls(%h);
         if ( $start_tls->code ) {
-            $self->logger->error( 'tls failed: ' . $start_tls->error );
-            return;
+            die 'tls failed: ' . $start_tls->error;
         }
     }
 
@@ -406,8 +405,7 @@ sub _ldap {
     my $bind =
       $ldap->bind( $self->{ldapBindDN}, password => $self->{ldapBindPassword} );
     if ( $bind->code ) {
-        $self->logger->error( 'bind failed: ' . $bind->error );
-        return;
+        die 'bind failed: ' . $bind->error;
     }
 
     $self->{ldap} = $ldap;
