@@ -6,7 +6,7 @@ use JSON;
 use Lemonldap::NG::Common::PSGI::Constants;
 use Lemonldap::NG::Common::PSGI::Request;
 
-our $VERSION = '1.9.991_01';
+our $VERSION = '2.0.3';
 
 our $_json = JSON->new->allow_nonref;
 
@@ -17,7 +17,7 @@ has languages    => ( is => 'rw', isa     => 'Str', default => 'en' );
 has logLevel     => ( is => 'rw', isa     => 'Str', default => 'info' );
 has portal       => ( is => 'rw', isa     => 'Str' );
 has staticPrefix => ( is => 'rw', isa     => 'Str' );
-has templateDir  => ( is => 'rw', isa     => 'Str' );
+has templateDir  => ( is => 'rw', isa     => 'Str|ArrayRef' );
 has links        => ( is => 'rw', isa     => 'ArrayRef' );
 has menuLinks    => ( is => 'rw', isa     => 'ArrayRef' );
 has logger     => ( is => 'rw' );
@@ -128,13 +128,6 @@ sub sendError {
     $err  ||= $req->error;
     $code ||= 500;
     $self->lmLog( "Error $code: $err", $code > 499 ? 'error' : 'notice' );
-    my $title = (
-          $code >= 500 ? 'Server error'
-        : $code == 403 ? 'Forbidden'
-        : $code == 401 ? 'Authentication required'
-        : $code == 400 ? 'Bad request'
-        :                'Error'
-    );
 
     # SOAP responses
     if ( $req->env->{HTTP_SOAPACTION} ) {
@@ -166,6 +159,13 @@ sub sendError {
 
     # Default response: HTML
     else {
+        my $title = (
+              $code >= 500 ? 'Server error'
+            : $code == 403 ? 'Forbidden'
+            : $code == 401 ? 'Authentication required'
+            : $code == 400 ? 'Bad request'
+            :                'Error'
+        );
         my $s = "<html><head><title>$title</title>
 <style>
 body{background:#000;color:#fff;padding:10px 50px;font-family:sans-serif;}a{text-decoration:none;color:#fff;}h1{text-align:center;}
@@ -174,7 +174,7 @@ body{background:#000;color:#fff;padding:10px 50px;font-family:sans-serif;}a{text
 <body>
 <h1>$title</h1>
 <p>$err</p>
-<center><a href=\"http://lemonldap-ng.org\">LemonLDAP::NG</a></center>'
+<center><a href=\"https://lemonldap-ng.org\">LemonLDAP::NG</a></center>
 </body>
 </html>";
         return [
@@ -190,7 +190,7 @@ body{background:#000;color:#fff;padding:10px 50px;font-family:sans-serif;}a{text
 
 sub abort {
     my ( $self, $err ) = @_;
-    $self->logger->error($err);
+    eval { $self->logger->error($err) };
     return sub {
         $self->sendError( Lemonldap::NG::Common::PSGI::Request->new( $_[0] ),
             $err, 500 );
@@ -225,7 +225,7 @@ sub sendJs {
         [
             'Content-Type'   => 'application/javascript',
             'Content-Length' => length($s),
-            'Cache-Control'  => 'max-age=2592000',
+            'Cache-Control'  => 'public,max-age=2592000',
         ],
         [$s]
     ];
@@ -241,7 +241,7 @@ sub sendHtml {
     $args{code} ||= 200;
     $args{headers} ||= $req->respHeaders || [];
     my $htpl;
-    $template = $self->templateDir . "/$template.tpl";
+    $template = ( $args{templateDir} // $self->templateDir ) . "/$template.tpl";
     return $self->sendError( $req, "Unable to read $template", 500 )
       unless ( -r $template and -f $template );
     eval {
@@ -250,10 +250,12 @@ sub sendHtml {
         $htpl = HTML::Template->new(
             filehandle             => IO::File->new($template),
             path                   => $self->templateDir,
+            search_path_on_include => 1,
             die_on_bad_params      => 0,
             die_on_missing_include => 1,
             cache                  => 0,
             global_vars            => 1,
+            loop_context_vars      => 1,
         );
 
         # TODO: replace app
@@ -285,6 +287,7 @@ sub sendHtml {
 
 sub run {
     my ( $self, $args ) = @_;
+    $args //= {};
     unless ( ref $self ) {
         $self = $self->new($args);
         return $self->abort( $self->error ) unless ( $self->init($args) );
@@ -479,7 +482,7 @@ Syslog facility. If empty, STDERR will be used for logging
 
 L<http://lemonldap-ng.org/>, L<Lemonldap::NG::Portal>, L<Lemonldap::NG::Handler>,
 L<Plack>, L<PSGI>, L<Lemonldap::NG::Common::PSGI::Router>,
-L<Lemonldap::NG::Common::PSGI::Request>, L<HTML::Template>, 
+L<Lemonldap::NG::Common::PSGI::Request>, L<HTML::Template>,
 
 =head1 AUTHORS
 
@@ -492,7 +495,7 @@ L<Lemonldap::NG::Common::PSGI::Request>, L<HTML::Template>,
 =head1 BUG REPORT
 
 Use OW2 system to report bug or ask for features:
-L<http://jira.ow2.org>
+L<https://gitlab.ow2.org/lemonldap-ng/lemonldap-ng/issues>
 
 =head1 DOWNLOAD
 
